@@ -1,8 +1,6 @@
 package Spreadsheet::Template;
-BEGIN {
-  $Spreadsheet::Template::AUTHORITY = 'cpan:DOY';
-}
-$Spreadsheet::Template::VERSION = '0.04';
+our $AUTHORITY = 'cpan:DOY';
+$Spreadsheet::Template::VERSION = '0.05';
 use Moose;
 # ABSTRACT: generate spreadsheets from a template
 
@@ -50,6 +48,14 @@ has _processor => (
     },
 );
 
+
+has json => (
+    is => 'ro',
+    default => sub {
+        return JSON->new;
+    }
+);
+
 sub _writer {
     my $self = shift;
     my $class = $self->writer_class;
@@ -64,7 +70,7 @@ sub render {
     my $contents = $self->_processor->process($template, $vars);
     # not decode_json, since we expect that we are already being handed a
     # character string (decode_json also decodes utf8)
-    my $data = from_json($contents);
+    my $data = $self->json->decode($contents);
     return $self->_writer->write($data);
 }
 
@@ -86,7 +92,7 @@ Spreadsheet::Template - generate spreadsheets from a template
 
 =head1 VERSION
 
-version 0.04
+version 0.05
 
 =head1 SYNOPSIS
 
@@ -135,6 +141,11 @@ template. Defaults to L<Spreadsheet::Template::Writer::XLSX>.
 
 Arguments to pass to the C<writer_class> constructor.
 
+=head2 json
+
+Instance of a JSON class that will handle decoding. Defaults to an instance of L<JSON>.
+Passing in a JSON obj with ->relaxed(1) set will allow for trailing commas in your templates.
+
 =head1 METHODS
 
 =head2 render($template, $vars)
@@ -515,7 +526,7 @@ Jesse Luehrs <doy@tozt.net>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2014 by Jesse Luehrs.
+This software is Copyright (c) 2015 by Jesse Luehrs.
 
 This is free software, licensed under:
 
