@@ -1,8 +1,6 @@
 package Spreadsheet::Template::Generator;
-BEGIN {
-  $Spreadsheet::Template::Generator::AUTHORITY = 'cpan:DOY';
-}
-$Spreadsheet::Template::Generator::VERSION = '0.04';
+our $AUTHORITY = 'cpan:DOY';
+$Spreadsheet::Template::Generator::VERSION = '0.05';
 use Moose;
 # ABSTRACT: create new templates from existing spreadsheets
 
@@ -63,7 +61,7 @@ Spreadsheet::Template::Generator - create new templates from existing spreadshee
 
 =head1 VERSION
 
-version 0.04
+version 0.05
 
 =head1 SYNOPSIS
 
@@ -106,7 +104,7 @@ Jesse Luehrs <doy@tozt.net>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2014 by Jesse Luehrs.
+This software is Copyright (c) 2015 by Jesse Luehrs.
 
 This is free software, licensed under:
 
