@@ -1,8 +1,6 @@
 package Spreadsheet::Template::Generator::Parser;
-BEGIN {
-  $Spreadsheet::Template::Generator::Parser::AUTHORITY = 'cpan:DOY';
-}
-$Spreadsheet::Template::Generator::Parser::VERSION = '0.04';
+our $AUTHORITY = 'cpan:DOY';
+$Spreadsheet::Template::Generator::Parser::VERSION = '0.05';
 use Moose::Role;
 # ABSTRACT: role for classes which parse an existing spreadsheet
 
@@ -26,7 +24,7 @@ Spreadsheet::Template::Generator::Parser - role for classes which parse an exist
 
 =head1 VERSION
 
-version 0.04
+version 0.05
 
 =head1 SYNOPSIS
 
@@ -58,7 +56,7 @@ Jesse Luehrs <doy@tozt.net>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2014 by Jesse Luehrs.
+This software is Copyright (c) 2015 by Jesse Luehrs.
 
 This is free software, licensed under:
 
