@@ -1,8 +1,6 @@
 package Spreadsheet::Template::Generator::Parser::Excel;
-BEGIN {
-  $Spreadsheet::Template::Generator::Parser::Excel::AUTHORITY = 'cpan:DOY';
-}
-$Spreadsheet::Template::Generator::Parser::Excel::VERSION = '0.04';
+our $AUTHORITY = 'cpan:DOY';
+$Spreadsheet::Template::Generator::Parser::Excel::VERSION = '0.05';
 use Moose::Role;
 
 use DateTime::Format::Excel;
