@@ -1,8 +1,6 @@
 package Spreadsheet::Template::Generator::Parser::XLSX;
-BEGIN {
-  $Spreadsheet::Template::Generator::Parser::XLSX::AUTHORITY = 'cpan:DOY';
-}
-$Spreadsheet::Template::Generator::Parser::XLSX::VERSION = '0.04';
+our $AUTHORITY = 'cpan:DOY';
+$Spreadsheet::Template::Generator::Parser::XLSX::VERSION = '0.05';
 use Moose;
 # ABSTRACT: parser for XLSX files
 
@@ -36,7 +34,7 @@ Spreadsheet::Template::Generator::Parser::XLSX - parser for XLSX files
 
 =head1 VERSION
 
-version 0.04
+version 0.05
 
 =head1 SYNOPSIS
 
@@ -55,7 +53,7 @@ Jesse Luehrs <doy@tozt.net>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2014 by Jesse Luehrs.
+This software is Copyright (c) 2015 by Jesse Luehrs.
 
 This is free software, licensed under:
 
