@@ -1,8 +1,6 @@
 package Spreadsheet::Template::Processor;
-BEGIN {
-  $Spreadsheet::Template::Processor::AUTHORITY = 'cpan:DOY';
-}
-$Spreadsheet::Template::Processor::VERSION = '0.04';
+our $AUTHORITY = 'cpan:DOY';
+$Spreadsheet::Template::Processor::VERSION = '0.05';
 use Moose::Role;
 # ABSTRACT: role for classes which preprocess a template file before rendering
 
@@ -26,7 +24,7 @@ Spreadsheet::Template::Processor - role for classes which preprocess a template
 
 =head1 VERSION
 
-version 0.04
+version 0.05
 
 =head1 SYNOPSIS
 
@@ -59,7 +57,7 @@ Jesse Luehrs <doy@tozt.net>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2014 by Jesse Luehrs.
+This software is Copyright (c) 2015 by Jesse Luehrs.
 
 This is free software, licensed under:
 
