@@ -1,8 +1,6 @@
 package Spreadsheet::Template::Processor::Identity;
-BEGIN {
-  $Spreadsheet::Template::Processor::Identity::AUTHORITY = 'cpan:DOY';
-}
-$Spreadsheet::Template::Processor::Identity::VERSION = '0.04';
+our $AUTHORITY = 'cpan:DOY';
+$Spreadsheet::Template::Processor::Identity::VERSION = '0.05';
 use Moose;
 # ABSTRACT: render a template file with no processing at all
 
@@ -33,7 +31,7 @@ Spreadsheet::Template::Processor::Identity - render a template file with no proc
 
 =head1 VERSION
 
-version 0.04
+version 0.05
 
 =head1 SYNOPSIS
 
@@ -54,7 +52,7 @@ Jesse Luehrs <doy@tozt.net>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2014 by Jesse Luehrs.
+This software is Copyright (c) 2015 by Jesse Luehrs.
 
 This is free software, licensed under:
 
