@@ -1,8 +1,6 @@
 package Spreadsheet::Template::Processor::Xslate;
-BEGIN {
-  $Spreadsheet::Template::Processor::Xslate::AUTHORITY = 'cpan:DOY';
-}
-$Spreadsheet::Template::Processor::Xslate::VERSION = '0.04';
+our $AUTHORITY = 'cpan:DOY';
+$Spreadsheet::Template::Processor::Xslate::VERSION = '0.05';
 use Moose;
 # ABSTRACT: preprocess templates with Xslate
 
@@ -56,7 +54,7 @@ Spreadsheet::Template::Processor::Xslate - preprocess templates with Xslate
 
 =head1 VERSION
 
-version 0.04
+version 0.05
 
 =head1 SYNOPSIS
 
@@ -124,7 +122,7 @@ Jesse Luehrs <doy@tozt.net>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2014 by Jesse Luehrs.
+This software is Copyright (c) 2015 by Jesse Luehrs.
 
 This is free software, licensed under:
 
