@@ -1,8 +1,6 @@
 package Spreadsheet::Template::Writer;
-BEGIN {
-  $Spreadsheet::Template::Writer::AUTHORITY = 'cpan:DOY';
-}
-$Spreadsheet::Template::Writer::VERSION = '0.04';
+our $AUTHORITY = 'cpan:DOY';
+$Spreadsheet::Template::Writer::VERSION = '0.05';
 use Moose::Role;
 # ABSTRACT: role for classes which write spreadsheet files from a template
 
@@ -26,7 +24,7 @@ Spreadsheet::Template::Writer - role for classes which write spreadsheet files f
 
 =head1 VERSION
 
-version 0.04
+version 0.05
 
 =head1 SYNOPSIS
 
@@ -60,7 +58,7 @@ Jesse Luehrs <doy@tozt.net>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2014 by Jesse Luehrs.
+This software is Copyright (c) 2015 by Jesse Luehrs.
 
 This is free software, licensed under:
 
