@@ -1,8 +1,6 @@
 package Spreadsheet::Template::Writer::Excel;
-BEGIN {
-  $Spreadsheet::Template::Writer::Excel::AUTHORITY = 'cpan:DOY';
-}
-$Spreadsheet::Template::Writer::Excel::VERSION = '0.04';
+our $AUTHORITY = 'cpan:DOY';
+$Spreadsheet::Template::Writer::Excel::VERSION = '0.05';
 use Moose::Role;
 
 use Class::Load 'load_class';
