@@ -1,8 +1,6 @@
 package Spreadsheet::Template::Writer::XLSX;
-BEGIN {
-  $Spreadsheet::Template::Writer::XLSX::AUTHORITY = 'cpan:DOY';
-}
-$Spreadsheet::Template::Writer::XLSX::VERSION = '0.04';
+our $AUTHORITY = 'cpan:DOY';
+$Spreadsheet::Template::Writer::XLSX::VERSION = '0.05';
 use Moose;
 # ABSTRACT: generate XLSX files from templates
 
@@ -31,7 +29,7 @@ Spreadsheet::Template::Writer::XLSX - generate XLSX files from templates
 
 =head1 VERSION
 
-version 0.04
+version 0.05
 
 =head1 SYNOPSIS
 
@@ -52,7 +50,7 @@ Jesse Luehrs <doy@tozt.net>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2014 by Jesse Luehrs.
+This software is Copyright (c) 2015 by Jesse Luehrs.
 
 This is free software, licensed under:
 
